from damask import __version__
from damask_parse.writers import write_load_case


def write_load(path, load_case):

    load_steps = []
    for step in load_case.steps:
        dct = step.to_dict()
        dct["def_grad_aim"] = dct.pop("target_def_grad", None)
        dct["def_grad_rate"] = dct.pop("target_def_grad_rate", None)
        load_steps.append(dct)

    write_load_case(
        dir_path=path.parent,
        load_cases=load_steps,
        name=path.name,
        write_2D_arrs=(__version__ != "3.0.0-alpha3"),
    )



import json
import matflow as mf
import h5py


def main_script_test(inputs_JSON_path, outputs_HDF5_path):
    with inputs_JSON_path.open("rt") as fp:
        inputs = json.load(fp)
    oris = mf.Orientations.from_random(number=inputs["num_orientations"])

    with h5py.File(outputs_HDF5_path, mode="w") as f:
        ori_grp = f.create_group("orientations")
        ori_grp.create_dataset(name="data", data=oris.data)
        ori_grp.attrs.create(
            name="representation",
            data=oris.representation.value,
        )
        ori_grp.attrs.create(
            name="unit_cell_alignment",
            data=[
                oris.unit_cell_alignment.x.value,
                oris.unit_cell_alignment.y.value,
                oris.unit_cell_alignment.z.value,
            ],
        )



import pytest
import matflow as mf


def pytest_configure(config):
    mf.run_time_info.in_pytest = True


def pytest_unconfigure(config):
    mf.run_time_info.in_pytest = False


@pytest.fixture
def null_config(tmp_path):
    if not mf.is_config_loaded:
        mf.load_config(config_dir=tmp_path)
    mf.run_time_info.in_pytest = True
